==> bayesDP_1.1.1.tar.gz: bayesDP/README.md <==
![alt text](https://raw.githubusercontent.com/balcomes/bayesDP/master/bayesDP-logo.png "bayesDP Logo")
======================================================================================================

bayesDP
=======

### Tools for the Bayesian Discount Prior Function

<https://cran.r-project.org/package=bayesDP>

Shiny app available at:

<https://mdic.shinyapps.io/bayesdp/>

[![Travis-CI Build
Status](https://travis-ci.org/balcomes/bayesDP.svg?branch=master)](https://travis-ci.org/balcomes/bayesDP)
[![Issue
Count](https://codeclimate.com/github/balcomes/bayesDP/badges/issue_count.svg)](https://codeclimate.com/github/balcomes/bayesDP)
[![Downloads](http://cranlogs.r-pkg.org/badges/bayesDP?color=brightgreen)](http://www.r-pkg.org/pkg/bayesDP)
[![Project Status: Active ? The project has reached a stable, usable
state and is being actively
developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

[![contributions
welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/balcomes/bayesDP/issues)
[![License](https://img.shields.io/badge/license-GPL%20%28%3E=%203%29-brightgreen.svg?style=flat)](http://www.gnu.org/licenses/gpl-3.0.html)
[![CRAN](http://www.r-pkg.org/badges/version/bayesDP)](https://cran.r-project.org/package=bayesDP)

### Description

Functions for data augmentation using the Bayesian discount prior
function for 1 arm and 2 arm clinical trials.

### CRAN Installation

Install release version from CRAN:

    install.packages("bayesDP")

### GitHub Installation

Install development version from GitHub:

    devtools::install_github("balcomes/bayesDP")

### Documentation

See manuals and vignettes within package.

### Examples

See manuals and vignettes within package.

### Authors

Shawn Balcome, Donnie Musgrove, Tarek Haddad and Christopher Jackson
(For the ppexp R code that was ported to C++.)

### License

GPL (&gt;= 3)

:apple: :tangerine: :lemon: :cherries:
[:watermelon:](http://codeology.braintreepayments.com/balcomes/bayesdp#)
:strawberry: :peach: :pear: :green\_apple:

==> bayesDP_1.2.1.tar.gz: bayesDP/README.md <==
<p align="center"><img src=https://raw.githubusercontent.com/donaldmusgrove/bayesDP/master/bayesDP-logo.png alt="bayesDP Logo" width="400" height="250"></p>

# bayesDP

### Tools for the Bayesian Discount Prior Function

<https://cran.r-project.org/package=bayesDP>

Shiny app available at:

<https://mdic.shinyapps.io/bayesdp/>

[![Travis-CI Build
Status](https://travis-ci.org/donaldmusgrove/bayesDP.svg?branch=master)](https://travis-ci.org/donaldmusgrove/bayesDP)
[![Issue
Count](https://codeclimate.com/github/donaldmusgrove/bayesDP/badges/issue_count.svg)](https://codeclimate.com/github/donaldmusgrove/bayesDP)
[![Downloads](http://cranlogs.r-pkg.org/badges/bayesDP?color=brightgreen)](http://www.r-pkg.org/pkg/bayesDP)
[![Project Status: Active ? The project has reached a stable, usable
state and is being actively
developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

[![contributions
welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/donaldmusgrove/bayesDP/issues)
[![License](https://img.shields.io/badge/license-GPL%20%28%3E=%203%29-brightgreen.svg?style=flat)](http://www.gnu.org/licenses/gpl-3.0.html)
[![CRAN](http://www.r-pkg.org/badges/version/bayesDP)](https://cran.r-project.org/package=bayesDP)

### Description

Functions for data augmentation using the Bayesian discount prior
function for 1 arm and 2 arm clinical trials.

### CRAN Installation

Install release version from CRAN:

    install.packages("bayesDP")

### GitHub Installation

Install development version from GitHub:

    devtools::install_github("donaldmusgrove/bayesDP")

### Documentation

See manuals and vignettes within package.

### Examples

See manuals and vignettes within package.

### Authors

Shawn Balcome, Donnie Musgrove, Tarek Haddad and Christopher Jackson
(For the ppexp R code that was ported to C++.)

### License

GPL (&gt;= 3)
